@@ -49,3 +49,51 @@ class TentacleNotFound(Exception):
     """
     Tentacle not found related Exception
     """
+
+
+class UninitializedCache(Exception):
+    """
+    Raised when a cache is requested but has not yet been initialized
+    """
+
+
+class NoCacheValue(Exception):
+    """
+    Raised when a cache value is selected but is not available in database
+    """
+
+
+class UncachableValue(Exception):
+    """
+    Raised when a cache value is selected but is not available in database
+    """
+
+
+class DatabaseNotFoundError(Exception):
+    """
+    Raised when a database can't be found
+    """
+
+
+class MissingDataError(Exception):
+    """
+    Raised when there is not enough available candles
+    """
+
+
+class MissingExchangeDataError(Exception):
+    """
+    Raised when there is no available data for this exchange
+    """
+
+
+class ExecutionAborted(Exception):
+    """
+    Raised when the current execution should be aborted
+    """
+
+
+class LogicalOperatorError(Exception):
+    """
+    Raised when a logical operation is invalid
+    """
